@@ -3,6 +3,7 @@
 
 from cow.server import Server
 from cow.plugins.motor_plugin import MotorPlugin
+from cow.plugins.redis_plugin import RedisPlugin
 
 from tests.sandbox.handlers.test import TestHandler
 
@@ -15,7 +16,8 @@ class SandboxServer(Server):
 
     def get_plugins(self):
         return [
-            MotorPlugin
+            MotorPlugin,
+            RedisPlugin
         ]
 
 if __name__ == '__main__':
